@@ -23,7 +23,7 @@ def save_yaml_to_file(indata, outfile, indent=None):
 def yaml_from_string(yaml_str):
     """Get dict from the string in yaml format."""
     try:
-        yamldata = yaml.load(yaml_str, Loader=FullLoader)
+        yamldata = yaml.load(yaml_str)
         return yamldata
     except:
         print('Failed to load yaml data: %s' % yaml_str)
